@@ -12,7 +12,7 @@ require Exporter;
 
 use vars qw($VERSION @ISA @EXPORT_OK);
 
-$VERSION = '1.10';
+$VERSION = '1.12';
 @ISA = qw(Exporter);
 @EXPORT_OK = qw(ReadCSV ReadJSON);
 
@@ -38,13 +38,13 @@ sub ReadCSV($$;$$)
         $raf = $file;
         $file = 'CSV file';
     } elsif (ref $file eq 'GLOB') {
-        $raf = new File::RandomAccess($file);
+        $raf = File::RandomAccess->new($file);
         $file = 'CSV file';
     } else {
         open CSVFILE, $file or return "Error opening CSV file '${file}'";
         binmode CSVFILE;
         $openedFile = 1;
-        $raf = new File::RandomAccess(\*CSVFILE);
+        $raf = File::RandomAccess->new(\*CSVFILE);
     }
     $delim = ',' unless defined $delim;
     # set input record separator by first newline found in the file
@@ -238,7 +238,7 @@ Tok: for (;;) {
 
 #------------------------------------------------------------------------------
 # Read JSON file
-# Inputs: 0) JSON file name, file ref or RAF ref, 1) database hash ref,
+# Inputs: 0) JSON file name, file ref, RAF ref or SCALAR ref, 1) database hash ref,
 #         2) flag to delete "-" tags, 3) character set
 # Returns: undef on success, or error string
 sub ReadJSON($$;$$)
@@ -253,13 +253,16 @@ sub ReadJSON($$;$$)
         $raf = $file;
         $file = 'JSON file';
     } elsif (ref $file eq 'GLOB') {
-        $raf = new File::RandomAccess($file);
+        $raf = File::RandomAccess->new($file);
         $file = 'JSON file';
+    } elsif (ref $file eq 'SCALAR') {
+        $raf = File::RandomAccess->new($file);
+        $file = 'in memory';
     } else {
         open JSONFILE, $file or return "Error opening JSON file '${file}'";
         binmode JSONFILE;
         $openedFile = 1;
-        $raf = new File::RandomAccess(\*JSONFILE);
+        $raf = File::RandomAccess->new(\*JSONFILE);
     }
     my $obj = ReadJSONObject($raf);
     close JSONFILE if $openedFile;
